Download and import an empty ICILS public use file (containing only the first data row) from the IEA homepage.
Usage
download_icils_iea(
year = c("2018", "2013"),
data_type = c("stud_dat", "stud_nat_dat", "stud_int_dat", "teach_dat", "teach_nat_dat",
"teach_int_dat", "school_dat", "school_nat_dat", "school_int_dat", "it_dat")
)
Arguments
- year
Year of the assessment.
- data_type
Type of the data.
Details
The function downloads a zip file from the IEA homepage into a temporary directory,
unzips it and imports the data with only a single data row via read_sav.
For downloading full ICILS data sets see the EdSurvey package.
The data is imported as a GADSdat object.
Examples
if (FALSE) { # interactive()
iea_icils <- download_icils_iea(year = "2018",
data_type = "stud_dat")
}